# JoBase
**Fast Python Game Library**

JoBase is a blazingly fast Python game library for beginner coders.
It is written in pure C and uses the GLFW library.
Please visit [jobase.org](https://jobase.org) for tutorials and documentation.
If you have any questions, please contact us at <hello@jobase.org>.

If you would like to support JoBase, please [raise an issue](https://github.com/JoBase/JoBase/issues/new) on GitHub when you find a problem.
For those who are familiar with compiling libraries in C, we would be very grateful if you could get JoBase working on MacOS devices.
Simply download the source code and install the packages listed in [wheels.yml](https://github.com/JoBase/JoBase/blob/main/.github/workflows/wheels.yml).
After that, you can attempt to compile JoBase according to the [setup.py](https://github.com/JoBase/JoBase/blob/main/setup.py) file.
